@@ -1,7 +1,7 @@
 from random import randint
 from .problem import Problem
 from .population import Population
-from .algorithm_genetic import GeneticAlgorithm, GeneticIndividual
+from .algorithm_genetic import GeneticAlgorithm
 from .operators import SwarmMutator, DummySelector, RandomGenerator, SwarmMutatorTVIW
 
 import time
@@ -14,13 +14,18 @@ class PSO(GeneticAlgorithm):
         self.n = self.options['max_population_size']
         self.mutator = SwarmMutator(self.problem.parameters)
         self.selector = DummySelector(self.problem.parameters, self.problem.signs)
+        self.features = {'velocity': [],
+                         'best_vector': [],
+                         'best_costs': []}
 
     def run(self):
         # set random generator
-        self.generator = RandomGenerator(self.problem.parameters, individual_class=GeneticIndividual)
+        self.generator = RandomGenerator(self.problem.parameters)
         self.generator.init(self.options['max_population_size'])
 
         population = self.gen_initial_population()
+        self.evaluate(population.individuals)
+        self.add_features(population.individuals)
 
         for individual in population.individuals:
             self.mutator.evaluate_best_individual(individual)
@@ -37,7 +42,7 @@ class PSO(GeneticAlgorithm):
 
             pareto_front = []
             for individual in offsprings:
-                if individual.front_number == 1:
+                if individual.features['front_number'] == 1:
                     pareto_front.append(individual)
 
             for individual in offsprings:
@@ -50,14 +55,13 @@ class PSO(GeneticAlgorithm):
             population = Population(offsprings)
             self.problem.populations.append(population)
             self.evaluator.evaluate(offsprings)
+            self.add_features(offsprings)
 
             for individual in offsprings:
                 self.mutator.evaluate_best_individual(individual)
 
             self.selector.sorting(offsprings)
 
-
-
             i += 1
 
         t = time.time() - t_s
@@ -66,6 +70,11 @@ class PSO(GeneticAlgorithm):
 
 class PSO_V1(GeneticAlgorithm):
     """
+
+    X. Li. A Non-dominated Sorting Particle Swarm Optimizer for Multiobjective
+    Optimization. In Genetic and Evolutionary Computation - GECCO 2003, volume
+    2723 of LNCS, pages 37–48, 2003.
+
     This algorithm is a variant of the original PSO, published by Eberhart(2000), the origin of this modified algorithm,
     which constriction factor was introduced by Clercs in 1999.
 
@@ -83,13 +92,15 @@ class PSO_V1(GeneticAlgorithm):
 
     def run(self):
         # set random generator
-        self.generator = RandomGenerator(self.problem.parameters, individual_class=GeneticIndividual)
+        self.generator = RandomGenerator(self.problem.parameters)
         self.generator.init(self.options['max_population_size'])
 
         population = self.gen_initial_population()
+        self.evaluate(population.individuals)
+        self.add_features(population.individuals)
 
         for individual in population.individuals:
-            self.mutator.evaluate_best_individual(individual)
+            self.mutator.evaluate_best_individual(individual)  # TODO: all evaluating should be derived from Evaluator class
 
         self.selector.sorting(population.individuals)
         self.problem.populations.append(population)
@@ -104,7 +115,7 @@ class PSO_V1(GeneticAlgorithm):
 
             pareto_front = []
             for individual in offsprings:
-                if individual.front_number == 1:
+                if individual.features['front_number'] == 1:
                     pareto_front.append(individual)
 
             for individual in offsprings:
@@ -115,6 +126,7 @@ class PSO_V1(GeneticAlgorithm):
                     self.mutator.mutate(individual)
 
             self.evaluate(offsprings)
+            self.add_features(offsprings)
 
             for individual in offsprings:
                 self.mutator.evaluate_best_individual(individual)
