@@ -22,14 +22,8 @@ class BinhAndKornProblem(Problem):
         function = BinhAndKorn()
         return function.eval(individual.vector)
 
-<<<<<<< HEAD
     def evaluate_constraints(self, individual):
         return BinhAndKorn.constraints(individual.vector)
-=======
-    def evaluate_constraints(self, x):
-        function = BinhAndKorn()
-        return function.constraints(x)
->>>>>>> 65f175f3f60f3670c6d91fa0e478f427944452c0
 
 
 class TestNSGA2Optimization(unittest.TestCase):
@@ -98,7 +92,7 @@ class TestAckley(unittest.TestCase):
             algorithm.run()
 
             b = Results(problem)
-            optimum = b.find_minimum('F_1')  # Takes last cost function
+            optimum = b.find_optimum('F_1')  # Takes last cost function
             self.assertAlmostEqual(optimum.costs[0], problem.global_optimum, 1)
         except AssertionError:
             # stochastic
@@ -119,7 +113,7 @@ class TestAlpine(unittest.TestCase):
             algorithm.run()
 
             b = Results(problem)
-            optimum = b.find_minimum('F_1')  # Takes last cost function
+            optimum = b.find_optimum('F_1')  # Takes last cost function
             self.assertAlmostEqual(optimum.costs[0], problem.global_optimum, 1)
         except AssertionError:
             # stochastic
